/*Main file for calculation MSOA zoomshock indices as discribed in De Fraja, Matheson, Rockey, 2020. "Zoomshock: The Geography and Local Labour Market Consequences of Working from Home"
Covid Economics, Issue 64, 13 January 2021, 1-41 (DMR)
*/

clear

**** Change this directory to the location of the replication files. Keep all files in the folder \final_public together.******** 
global directory = "C:\Users\ec1jam\Dropbox\Geographic and Social Mobility\Covid\PublicData\PublicZoomshock\final_public"
*********************************************************************************************************************************




insheet using "$directory\MSOA_resident_occupation.csv", names   /** Reading in residential count by 2d SOC code and MSOA**/

do "$directory\homework_2d"			/** This file calculates a weighted work-from-home index for 2-digit SOC using data from the Quarterly Labour Force Survey**/

	gen resid_flow = 0					/** resid_flow is the number of residents in an MSOA who can do their jobs from home **/

	foreach soc in $SOC2D{
		replace resid_flow = resid_flow + occ`soc'*HW`soc' 
		}
 
	gen resid_home = resid_flow/all_resident 			/** % of residents in an MSOA who can do their jobs from home **/

	drop occ*

save "$directory\resid_temp", replace


clear
insheet using "$directory\MSOA_work_occupation.csv", names  /** Reading in worker count by 3d SOC code and MSOA**/
	do "$directory\homework_3d"			/** This file calculates a weighted work-from-home index for 3-digit SOC using data from the Quarterly Labour Force Survey**/

	gen work_flow = 0					/** work_flow is the number of workers in an MSOA who can do their jobs from home **/

	foreach soc in $SOC3D{
		replace work_flow = work_flow + occ`soc'*HW`soc' 
		}	
	
	gen work_home = work_flow/all_employees 		/** % of workers in an MSOA who can do their jobs from home **/
	
drop occ*


merge 1:1 msoa11cd msoa_name using "$directory\resid_temp"
	drop if _merge==1
	drop _merge

gen zoomshock = resid_flow - work_flow 				/** Equation 2 in DMR **/

merge 1:1 msoa11cd using "$directory\LA_codes"		/* Labeling local authorities by name */
	drop _merge


/* Below makes and merges in MSOA-level IMD */
	
	do "$directory\IMD_make.do"	
	
		merge 1:1 msoa11cd using "$directory\IMD_byMSOA"
		drop _merge imd19

/* A little bit of tidying up */

order la_code la_name msoa11cd msoa_name all_employees work_flow work_home all_resident resid_flow resid_home zoomshock IMD

label var msoa11cd "MSOA code" 	
label var msoa_name "MSOA name"
label var all_employees "Total number of workers working in MSOA"
label var work_flow "Workers working in MSOA who can remote work"
label var work_home "Proportion of workers working in MSOA who can remote work"
label var all_resident "Total number of workers living in MSOA"
label var resid_flow "Workers living in MSOA who can remote work"
label var resid_home "Proportion of workers living in MSOA who can remote work"
label var zoomshock "Zoomshock, net worker flow due to remote working (Equation 2)"
label var IMD "index of multiple deprivation (average for MSOA)"
	
save "$directory\MSOA_zoomshock.dta", replace

